@@ -2,7 +2,7 @@ package Sub::Uplevel;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 # We must override *CORE::GLOBAL::caller if it hasn't already been 
 # overridden or else Perl won't see our local override later.
@@ -19,9 +19,13 @@ require Exporter;
 
 Sub::Uplevel - apparently run a function in a higher stack frame
 
-=head1 VERSION
+=begin wikidoc
 
-This documentation describes version 0.18
+= VERSION
+
+This documentation describes version %%VERSION%%
+
+=end wikidoc
 
 =head1 SYNOPSIS
 
@@ -102,18 +106,30 @@ sub uplevel {
     return $func->(@args);
 }
 
-sub _normal_caller (;$) {
+sub _normal_caller (;$) { ## no critic Prototypes
     my $height = $_[0];
     $height++;
-    if( wantarray and !@_ ) {
-        return (CORE::caller($height))[0..2];
+    if ( CORE::caller() eq 'DB' ) {
+        # passthrough the @DB::args trick
+        package DB;
+        if( wantarray and !@_ ) {
+            return (CORE::caller($height))[0..2];
+        }
+        else {
+            return CORE::caller($height);
+        }
     }
     else {
-        return CORE::caller($height);
+        if( wantarray and !@_ ) {
+            return (CORE::caller($height))[0..2];
+        }
+        else {
+            return CORE::caller($height);
+        }
     }
 }
 
-sub _uplevel_caller (;$) {
+sub _uplevel_caller (;$) { ## no critic Prototypes
     my $height = $_[0] || 0;
 
     # shortcut if no uplevels have been called
@@ -193,7 +209,15 @@ found during the search
 
     # For returning values, we pass through the call to the proxy caller
     # function, just at a higher stack level
-    my @caller = $Caller_Proxy->($height + $adjust + 1);
+    my @caller;
+    if ( CORE::caller() eq 'DB' ) {
+        # passthrough the @DB::args trick
+        package DB;
+        @caller = $Sub::Uplevel::Caller_Proxy->($height + $adjust + 1);
+    }
+    else {
+        @caller = $Caller_Proxy->($height + $adjust + 1);
+    }
 
     if( wantarray ) {
         if( !@_ ) {
@@ -259,7 +283,7 @@ Michael G Schwern E<lt>schwern@pobox.comE<gt> (original author)
 =head1 LICENSE
 
 Original code Copyright (c) 2001 to 2007 by Michael G Schwern.
-Additional code Copyright (c) 2006 to 2007 by David A Golden.
+Additional code Copyright (c) 2006 to 2008 by David A Golden.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
